korail2 is written and maintained by Taehoon Kim and
various contributors:

Development Lead
````````````````

- Taehoon Kim <carpedm20@gmail.com> `@carpedm20 <https://github.com/carpedm20>`_

Core Contributors
`````````````````

- Hanson Kim <sng2nara@gmail.com> `@sng2c <https://github.com/sng2c>`_
- Hyeshik Chang <hyeshik@snu.ac.kr> `@hyeshik <https://github.com/hyeshik>`_
